@@ -24,6 +24,7 @@
 #include "npapi.h"
 #include "npupp.h"
 #include <unistd.h>
+#include <string.h>
 
 static NPNetscapeFuncs mozilla_funcs;
 static int pid = 0;
@@ -163,7 +164,6 @@ static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
 
 static void ChemPrint (NPP instance, NPPrint *platformPrint)
 {
-#warning TODO: implement !!!
 }
 
 static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
@@ -197,7 +197,8 @@ char *NP_GetMIMEDescription (void)
 {
 	return ("chemical/x-xyz:xyz:XYZ Coordinate Format;"
 			"chemical/x-mdl-molfile:mol:MDL Molfile;"
-			"chemical/x-pdb:pdb,ent:Protein DataBank");
+			"chemical/x-pdb:pdb,ent:Protein DataBank;"
+			"application/x-gcrystal:gcrystal:Crystalline structure model");
 }
 
 /* This is called to initialise the plugin
