@@ -4,7 +4,7 @@
  * Gnome Crystal
  * linesdlg.cc 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,6 +26,7 @@
 #include "linesdlg.h"
 #include "document.h"
 #include "application.h"
+#include <glib/gi18n.h>
 
 enum
 {
@@ -89,10 +90,14 @@ static void on_medians_toggled (GtkToggleButton* btn, gcLinesDlg *pBox)
 	pBox->OnToggledSpecial (medians);
 }
 
-gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, DATADIR"/gchemutils-unstable/glade/crystal/lines.glade", "lines")
+gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, GLADEDIR"/lines.glade", "lines", pDoc)
 {
+	if (!xml) {
+		m_Lines = NULL;
+		delete this;
+		return;
+	}
 	m_pDoc = pDoc;
-	pDoc->NotifyDialog (this);
 	GtkWidget* button = glade_xml_get_widget (xml, "add");
 	g_signal_connect (G_OBJECT (button), "clicked", GTK_SIGNAL_FUNC (on_add), this);
 	DeleteBtn = glade_xml_get_widget (xml, "delete");
@@ -272,7 +277,8 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, DATA
 
 gcLinesDlg::~gcLinesDlg ()
 {
-	m_pDoc->RemoveDialog (this);
+	if (m_Lines)
+		g_array_free (m_Lines, false);
 }
 
 bool gcLinesDlg::Apply ()
@@ -341,7 +347,7 @@ bool gcLinesDlg::Apply ()
 		Lines->push_back (new CrystalLine((s->duplicated)? normal: gcu::unique, s->x1, s->y1, s->z1, s->x2, s->y2, s->z2, s->r, (float)s->Red, (float)s->Green, (float)s->Blue, (float)s->Alpha));
 	}
 	m_pDoc->Update ();
-	m_pDoc->SetDirty ();
+	m_pDoc->SetDirty (true);
 	return true;
 }
 
@@ -428,6 +434,7 @@ void gcLinesDlg::LineSelect (GtkTreeSelection *Selection)
 		tmp = g_strdup_printf ("%g", g_array_index (m_Lines, struct LineStruct, m_LineSelected).r);
 		gtk_entry_set_text (LineR, tmp);
 		g_free (tmp);
+		gtk_tree_path_free (path);
 	} else {
 		gtk_widget_set_sensitive (DeleteBtn, false);
 		if (!m_Lines->len) gtk_widget_set_sensitive (DeleteAllBtn, false);
@@ -465,6 +472,7 @@ void gcLinesDlg::OnEdited (GtkCellRendererText *cell, const gchar *path_string,
 		g_array_index (m_Lines, struct LineStruct, m_LineSelected).z2 = x;
 		break;
 	}
+	gtk_tree_path_free (path);
 }
 
 void gcLinesDlg::OnToggled (GtkCellRendererToggle *cell, const gchar *path_string)
@@ -477,7 +485,8 @@ void gcLinesDlg::OnToggled (GtkCellRendererToggle *cell, const gchar *path_strin
 	gtk_tree_model_get (GTK_TREE_MODEL (LineList), &iter, COLUMN_SINGLE, &single, -1);
 	single ^= 1;
 	gtk_list_store_set (LineList, &iter, COLUMN_SINGLE, single, -1);
-	g_array_index (m_Lines, struct LineStruct, m_LineSelected).duplicated = !single;
+	g_array_index (m_Lines, struct LineStruct, gtk_tree_path_get_indices (path)[0]).duplicated = !single;
+	gtk_tree_path_free (path);
 }
 
 void gcLinesDlg::OnToggledSpecial (int Type)
